import * as lsp from "vscode-languageserver-protocol";
import { TSLanguageServiceConfig, TSLanguageServiceOptions, WorkDoneProgressReporter } from "./types";
import { TSLspConverter } from "./utils/converter";
export interface TSLanguageServiceDelegate {
    converter: TSLspConverter;
    openExternal: (uri: lsp.URI) => Promise<boolean>;
    logMessage: (type: lsp.MessageType, message: string) => void;
    showMessage: (type: lsp.MessageType, message: string, ...actions: lsp.MessageActionItem[]) => Promise<lsp.MessageActionItem | null>;
    openTextDocument(uri: lsp.URI, focus?: boolean): Promise<boolean>;
    applyWorkspaceEdit(edit: lsp.WorkspaceEdit): Promise<boolean>;
    createWorkDoneProgress: () => Promise<WorkDoneProgressReporter | undefined>;
}
export type TSLanguageService = ReturnType<typeof createTSLanguageService>;
export declare function createTSLanguageService(initOptions: TSLanguageServiceOptions): {
    initialized(): boolean;
    waitInitialized(): Promise<void>;
    initialize(config: TSLanguageServiceConfig | undefined): Promise<void>;
    dispose(): void;
    changeConfiguration(params: lsp.DidChangeConfigurationParams): void;
    openTextDocument(params: lsp.DidOpenTextDocumentParams): void;
    changeTextDocument(params: lsp.DidChangeTextDocumentParams): void;
    closeTextDocument(params: lsp.DidCloseTextDocumentParams): void;
    renameFiles(params: lsp.RenameFilesParams): void;
    changeWorkspaceFolders(params: lsp.DidChangeWorkspaceFoldersParams): void;
    completion: (params: lsp.CompletionParams, token?: lsp.CancellationToken | undefined) => Promise<lsp.CompletionList>;
    completionItemResolve: (item: lsp.CompletionItem, token?: lsp.CancellationToken | undefined) => Promise<lsp.CompletionItem>;
    documentHighlight: (params: lsp.DocumentHighlightParams, token?: lsp.CancellationToken | undefined) => Promise<{
        range: lsp.Range;
        kind: lsp.DocumentHighlightKind;
    }[] | undefined>;
    signatureHelp: (params: lsp.SignatureHelpParams, token?: lsp.CancellationToken | undefined) => Promise<lsp.SignatureHelp | undefined>;
    definition: (params: lsp.DefinitionParams, token?: lsp.CancellationToken | undefined) => Promise<lsp.Location | lsp.Location[] | undefined>;
    references: (params: lsp.ReferenceParams, token?: lsp.CancellationToken | undefined) => Promise<lsp.Location[] | undefined>;
    hover: (params: lsp.HoverParams, token?: lsp.CancellationToken | undefined) => Promise<lsp.Hover | undefined>;
    documentSymbol: (params: lsp.DocumentSymbolParams, token?: lsp.CancellationToken | undefined) => Promise<lsp.DocumentSymbol[] | lsp.SymbolInformation[] | undefined>;
    workspaceSymbol: (params: lsp.WorkspaceSymbolParams, token?: lsp.CancellationToken | undefined) => Promise<lsp.SymbolInformation[] | undefined>;
    codeAction: (params: lsp.CodeActionParams, token?: lsp.CancellationToken | undefined) => Promise<(lsp.Command | lsp.CodeAction)[] | null>;
    codeActionResolve: (item: lsp.CodeAction, token?: lsp.CancellationToken | undefined) => Promise<lsp.CodeAction>;
    executeCommand: (params: lsp.ExecuteCommandParams) => Promise<unknown>;
    implementation: (params: lsp.ImplementationParams, token?: lsp.CancellationToken | undefined) => Promise<lsp.Location | lsp.Location[] | undefined>;
    typeDefinition: (params: lsp.TypeDefinitionParams, token?: lsp.CancellationToken | undefined) => Promise<lsp.Location | lsp.Location[] | undefined>;
    documentFormatting: (params: lsp.DocumentFormattingParams, token?: lsp.CancellationToken | undefined) => Promise<lsp.TextEdit[] | undefined>;
    documentRangeFormatting: (params: lsp.DocumentRangeFormattingParams, token?: lsp.CancellationToken | undefined) => Promise<lsp.TextEdit[] | undefined>;
    documentOnTypeFormatting: (params: lsp.DocumentOnTypeFormattingParams, token?: lsp.CancellationToken | undefined) => Promise<lsp.TextEdit[] | undefined>;
    prepareRename: (params: lsp.PrepareRenameParams, token?: lsp.CancellationToken | undefined) => Promise<lsp.Range | {
        range: lsp.Range;
        placeholder: string;
    } | undefined>;
    rename: (params: lsp.RenameParams, token?: lsp.CancellationToken | undefined) => Promise<lsp.WorkspaceEdit | undefined>;
    foldingRanges: (params: lsp.FoldingRangeParams, token?: lsp.CancellationToken | undefined) => Promise<lsp.FoldingRange[] | undefined>;
    selectionRanges: (params: lsp.SelectionRangeParams, token?: lsp.CancellationToken | undefined) => Promise<lsp.SelectionRange[] | undefined>;
    prepareCallHierarchy: (params: lsp.CallHierarchyPrepareParams, token?: lsp.CancellationToken | undefined) => Promise<lsp.CallHierarchyItem[] | null>;
    incomingCalls: (params: lsp.CallHierarchyIncomingCallsParams, token?: lsp.CancellationToken | undefined) => Promise<lsp.CallHierarchyIncomingCall[] | null>;
    outgoingCalls: (params: lsp.CallHierarchyOutgoingCallsParams, token?: lsp.CancellationToken | undefined) => Promise<lsp.CallHierarchyOutgoingCall[] | null>;
    inlayHint: (params: lsp.InlayHintParams, token?: lsp.CancellationToken | undefined) => Promise<lsp.InlayHint[] | null>;
    codeLens: (params: lsp.CodeLensParams, token?: lsp.CancellationToken | undefined) => Promise<lsp.CodeLens[] | undefined>;
    codeLensResolve: (item: lsp.CodeLens, token?: lsp.CancellationToken | undefined) => Promise<lsp.CodeLens>;
    semanticTokensFull: (params: lsp.SemanticTokensParams, token?: lsp.CancellationToken | undefined) => Promise<lsp.SemanticTokens>;
    semanticTokensRange: (params: lsp.SemanticTokensRangeParams, token?: lsp.CancellationToken | undefined) => Promise<lsp.SemanticTokens>;
    onShowDocument(handler: (params: lsp.ShowDocumentParams) => Promise<boolean>): lsp.Disposable;
    onLogMessage(handler: (params: lsp.LogMessageParams) => void): lsp.Disposable;
    onShowMessage(handler: (params: lsp.ShowMessageRequestParams) => Promise<lsp.MessageActionItem | null>): lsp.Disposable;
    onApplyWorkspaceEdit(handler: (params: lsp.ApplyWorkspaceEditParams) => Promise<lsp.ApplyWorkspaceEditResult>): lsp.Disposable;
    onWorkDoneProgress(handler: () => Promise<WorkDoneProgressReporter>): lsp.Disposable;
    onDiagnostics(handler: (params: lsp.PublishDiagnosticsParams) => Promise<void>): lsp.Disposable;
};
